/*
 * KRYView.java
 */

package kry;

import java.awt.Image;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.jdesktop.application.Action;
import org.jdesktop.application.ResourceMap;
import org.jdesktop.application.SingleFrameApplication;
import org.jdesktop.application.FrameView;
import org.jdesktop.application.TaskMonitor;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.File;
import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.BitSet;
import javax.imageio.ImageIO;
import javax.swing.Timer;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.filechooser.FileFilter;


/**
 * The application's main frame.
 */
public class KRYView extends FrameView {

    BufferedImage vstup;
    BufferedImage vystup;
    BitSet bitovepole;
    String soubor;
    String md5;

    private FileFilter ff = new FileFilter() {
        public boolean accept(File pathname) {
            String filename = pathname.getName();
            return filename.endsWith(".bmp") || pathname.isDirectory();
        }
        @Override
        public String getDescription() {
            return "BITMAP file format | *.bmp";
        }
    };

    public KRYView(SingleFrameApplication app) {
        super(app);

        initComponents();

        // status bar initialization - message timeout, idle icon and busy animation, etc
        ResourceMap resourceMap = getResourceMap();
        int messageTimeout = resourceMap.getInteger("StatusBar.messageTimeout");
        messageTimer = new Timer(messageTimeout, new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                statusMessageLabel.setText("");
            }
        });
        messageTimer.setRepeats(false);
        int busyAnimationRate = resourceMap.getInteger("StatusBar.busyAnimationRate");
        for (int i = 0; i < busyIcons.length; i++) {
            busyIcons[i] = resourceMap.getIcon("StatusBar.busyIcons[" + i + "]");
        }
        busyIconTimer = new Timer(busyAnimationRate, new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                busyIconIndex = (busyIconIndex + 1) % busyIcons.length;
                statusAnimationLabel.setIcon(busyIcons[busyIconIndex]);
            }
        });
        idleIcon = resourceMap.getIcon("StatusBar.idleIcon");
        statusAnimationLabel.setIcon(idleIcon);
        progressBar.setVisible(true);

        // connecting action tasks to status bar via TaskMonitor
        TaskMonitor taskMonitor = new TaskMonitor(getApplication().getContext());
        taskMonitor.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                String propertyName = evt.getPropertyName();
                if ("started".equals(propertyName)) {
                    if (!busyIconTimer.isRunning()) {
                        statusAnimationLabel.setIcon(busyIcons[0]);
                        busyIconIndex = 0;
                        busyIconTimer.start();
                    }
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(true);
                } else if ("done".equals(propertyName)) {
                    busyIconTimer.stop();
                    statusAnimationLabel.setIcon(idleIcon);
                    progressBar.setVisible(false);
                    progressBar.setValue(0);
                } else if ("message".equals(propertyName)) {
                    String text = (String)(evt.getNewValue());
                    statusMessageLabel.setText((text == null) ? "" : text);
                    messageTimer.restart();
                } else if ("progress".equals(propertyName)) {
                    int value = (Integer)(evt.getNewValue());
                    progressBar.setVisible(true);
                    progressBar.setIndeterminate(false);
                    progressBar.setValue(value);
                }
            }
        });
    }

    @Action
    public void showAboutBox() {
        if (aboutBox == null) {
            JFrame mainFrame = KRYApp.getApplication().getMainFrame();
            aboutBox = new KRYAboutBox(mainFrame);
            aboutBox.setLocationRelativeTo(mainFrame);
        }
        KRYApp.getApplication().show(aboutBox);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        mainPanel = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        jLabel2 = new javax.swing.JLabel();
        TXT_soubor = new javax.swing.JTextField();
        jScrollPane1 = new javax.swing.JScrollPane();
        TXT_text = new javax.swing.JTextArea();
        BUT_prochazet = new javax.swing.JButton();
        BUT_encode = new javax.swing.JButton();
        BUT_decode = new javax.swing.JButton();
        IMG_obrazek1 = new kry.JPictureGUI();
        IMG_obrazek2 = new kry.JPictureGUI();
        jLabel3 = new javax.swing.JLabel();
        TXT_MD5 = new javax.swing.JTextField();
        jLabel4 = new javax.swing.JLabel();
        jLabel5 = new javax.swing.JLabel();
        menuBar = new javax.swing.JMenuBar();
        javax.swing.JMenu fileMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem exitMenuItem = new javax.swing.JMenuItem();
        javax.swing.JMenu helpMenu = new javax.swing.JMenu();
        javax.swing.JMenuItem aboutMenuItem = new javax.swing.JMenuItem();
        statusPanel = new javax.swing.JPanel();
        javax.swing.JSeparator statusPanelSeparator = new javax.swing.JSeparator();
        statusMessageLabel = new javax.swing.JLabel();
        statusAnimationLabel = new javax.swing.JLabel();
        progressBar = new javax.swing.JProgressBar();
        FCH_soubor = new javax.swing.JFileChooser();

        mainPanel.setName("mainPanel"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(kry.KRYApp.class).getContext().getResourceMap(KRYView.class);
        jLabel1.setText(resourceMap.getString("jLabel1.text")); // NOI18N
        jLabel1.setName("jLabel1"); // NOI18N

        jLabel2.setText(resourceMap.getString("jLabel2.text")); // NOI18N
        jLabel2.setName("jLabel2"); // NOI18N

        TXT_soubor.setText(resourceMap.getString("TXT_soubor.text")); // NOI18N
        TXT_soubor.setName("TXT_soubor"); // NOI18N

        jScrollPane1.setHorizontalScrollBarPolicy(javax.swing.ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        jScrollPane1.setName("jScrollPane1"); // NOI18N

        TXT_text.setColumns(20);
        TXT_text.setFont(resourceMap.getFont("TXT_text.font")); // NOI18N
        TXT_text.setLineWrap(true);
        TXT_text.setRows(5);
        TXT_text.setText(resourceMap.getString("TXT_text.text")); // NOI18N
        TXT_text.setName("TXT_text"); // NOI18N
        jScrollPane1.setViewportView(TXT_text);

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(kry.KRYApp.class).getContext().getActionMap(KRYView.class, this);
        BUT_prochazet.setAction(actionMap.get("nacistObrazek")); // NOI18N
        BUT_prochazet.setText(resourceMap.getString("BUT_prochazet.text")); // NOI18N
        BUT_prochazet.setName("BUT_prochazet"); // NOI18N

        BUT_encode.setAction(actionMap.get("zakodovatText")); // NOI18N
        BUT_encode.setText(resourceMap.getString("BUT_encode.text")); // NOI18N
        BUT_encode.setName("BUT_encode"); // NOI18N

        BUT_decode.setAction(actionMap.get("rozkodovatText")); // NOI18N
        BUT_decode.setText(resourceMap.getString("BUT_decode.text")); // NOI18N
        BUT_decode.setName("BUT_decode"); // NOI18N

        IMG_obrazek1.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        IMG_obrazek1.setName("IMG_obrazek1"); // NOI18N
        IMG_obrazek1.setPreferredSize(new java.awt.Dimension(150, 210));

        javax.swing.GroupLayout IMG_obrazek1Layout = new javax.swing.GroupLayout(IMG_obrazek1);
        IMG_obrazek1.setLayout(IMG_obrazek1Layout);
        IMG_obrazek1Layout.setHorizontalGroup(
            IMG_obrazek1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 146, Short.MAX_VALUE)
        );
        IMG_obrazek1Layout.setVerticalGroup(
            IMG_obrazek1Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 212, Short.MAX_VALUE)
        );

        IMG_obrazek2.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        IMG_obrazek2.setName("IMG_obrazek2"); // NOI18N
        IMG_obrazek2.setPreferredSize(new java.awt.Dimension(150, 210));

        javax.swing.GroupLayout IMG_obrazek2Layout = new javax.swing.GroupLayout(IMG_obrazek2);
        IMG_obrazek2.setLayout(IMG_obrazek2Layout);
        IMG_obrazek2Layout.setHorizontalGroup(
            IMG_obrazek2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 146, Short.MAX_VALUE)
        );
        IMG_obrazek2Layout.setVerticalGroup(
            IMG_obrazek2Layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 212, Short.MAX_VALUE)
        );

        jLabel3.setText(resourceMap.getString("jLabel3.text")); // NOI18N
        jLabel3.setName("jLabel3"); // NOI18N

        TXT_MD5.setText(resourceMap.getString("TXT_MD5.text")); // NOI18N
        TXT_MD5.setName("TXT_MD5"); // NOI18N

        jLabel4.setText(resourceMap.getString("jLabel4.text")); // NOI18N
        jLabel4.setName("jLabel4"); // NOI18N

        jLabel5.setText(resourceMap.getString("jLabel5.text")); // NOI18N
        jLabel5.setName("jLabel5"); // NOI18N

        javax.swing.GroupLayout mainPanelLayout = new javax.swing.GroupLayout(mainPanel);
        mainPanel.setLayout(mainPanelLayout);
        mainPanelLayout.setHorizontalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(mainPanelLayout.createSequentialGroup()
                        .addContainerGap()
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(mainPanelLayout.createSequentialGroup()
                                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                    .addComponent(jLabel1)
                                    .addComponent(jLabel2))
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                                    .addGroup(mainPanelLayout.createSequentialGroup()
                                        .addComponent(TXT_soubor, javax.swing.GroupLayout.DEFAULT_SIZE, 447, Short.MAX_VALUE)
                                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                                        .addComponent(BUT_prochazet))
                                    .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 534, Short.MAX_VALUE)))
                            .addGroup(mainPanelLayout.createSequentialGroup()
                                .addComponent(BUT_encode)
                                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                                .addComponent(BUT_decode))))
                    .addGroup(mainPanelLayout.createSequentialGroup()
                        .addGap(56, 56, 56)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(IMG_obrazek1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabel4))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(IMG_obrazek2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                            .addComponent(jLabel5))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addGroup(mainPanelLayout.createSequentialGroup()
                                .addComponent(jLabel3)
                                .addGap(8, 8, 8))
                            .addComponent(TXT_MD5, javax.swing.GroupLayout.DEFAULT_SIZE, 224, Short.MAX_VALUE))))
                .addContainerGap())
        );
        mainPanelLayout.setVerticalGroup(
            mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(mainPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel1)
                    .addComponent(TXT_soubor, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(BUT_prochazet))
                .addGap(18, 18, 18)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jLabel2)
                    .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, 143, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(BUT_encode)
                    .addComponent(BUT_decode))
                .addGap(18, 18, 18)
                .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(mainPanelLayout.createSequentialGroup()
                        .addComponent(jLabel3)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(TXT_MD5, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, mainPanelLayout.createSequentialGroup()
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                            .addComponent(jLabel4)
                            .addComponent(jLabel5))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(mainPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
                            .addComponent(IMG_obrazek2, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 216, Short.MAX_VALUE)
                            .addComponent(IMG_obrazek1, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 216, Short.MAX_VALUE))))
                .addContainerGap())
        );

        menuBar.setName("menuBar"); // NOI18N

        fileMenu.setText(resourceMap.getString("fileMenu.text")); // NOI18N
        fileMenu.setName("fileMenu"); // NOI18N

        exitMenuItem.setAction(actionMap.get("quit")); // NOI18N
        exitMenuItem.setText(resourceMap.getString("exitMenuItem.text")); // NOI18N
        exitMenuItem.setToolTipText(resourceMap.getString("exitMenuItem.toolTipText")); // NOI18N
        exitMenuItem.setName("exitMenuItem"); // NOI18N
        fileMenu.add(exitMenuItem);

        menuBar.add(fileMenu);

        helpMenu.setText(resourceMap.getString("helpMenu.text")); // NOI18N
        helpMenu.setName("helpMenu"); // NOI18N

        aboutMenuItem.setAction(actionMap.get("showAboutBox")); // NOI18N
        aboutMenuItem.setText(resourceMap.getString("aboutMenuItem.text")); // NOI18N
        aboutMenuItem.setName("aboutMenuItem"); // NOI18N
        helpMenu.add(aboutMenuItem);

        menuBar.add(helpMenu);

        statusPanel.setName("statusPanel"); // NOI18N

        statusPanelSeparator.setName("statusPanelSeparator"); // NOI18N

        statusMessageLabel.setName("statusMessageLabel"); // NOI18N

        statusAnimationLabel.setHorizontalAlignment(javax.swing.SwingConstants.LEFT);
        statusAnimationLabel.setName("statusAnimationLabel"); // NOI18N

        progressBar.setName("progressBar"); // NOI18N

        javax.swing.GroupLayout statusPanelLayout = new javax.swing.GroupLayout(statusPanel);
        statusPanel.setLayout(statusPanelLayout);
        statusPanelLayout.setHorizontalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(statusPanelSeparator, javax.swing.GroupLayout.DEFAULT_SIZE, 602, Short.MAX_VALUE)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addContainerGap()
                .addComponent(statusMessageLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 432, Short.MAX_VALUE)
                .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(statusAnimationLabel)
                .addContainerGap())
        );
        statusPanelLayout.setVerticalGroup(
            statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(statusPanelLayout.createSequentialGroup()
                .addComponent(statusPanelSeparator, javax.swing.GroupLayout.PREFERRED_SIZE, 2, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addGroup(statusPanelLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(statusMessageLabel)
                    .addComponent(statusAnimationLabel)
                    .addComponent(progressBar, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(3, 3, 3))
        );

        FCH_soubor.setCurrentDirectory(new File(System.getProperty("user.dir")));
        FCH_soubor.setFileFilter(ff);
        FCH_soubor.setName("FCH_soubor"); // NOI18N

        setComponent(mainPanel);
        setMenuBar(menuBar);
        setStatusBar(statusPanel);
    }// </editor-fold>//GEN-END:initComponents

    @Action
    public void nacistObrazek() {
        int returnVal = this.FCH_soubor.showOpenDialog(this.mainPanel);
        if (returnVal == JFileChooser.APPROVE_OPTION) {
            TXT_soubor.setText(this.FCH_soubor.getSelectedFile().getAbsolutePath());
            soubor = FCH_soubor.getSelectedFile().getName().substring(0, FCH_soubor.getSelectedFile().getName().indexOf("."));
            try {
                vstup = ImageIO.read(FCH_soubor.getSelectedFile());
            } catch (IOException ex) {System.err.println("Chyba pri otvirani souboru!");}
            IMG_obrazek2.setImage(null);
            IMG_obrazek2.repaint();
            IMG_obrazek1.setImage(vstup);
            IMG_obrazek1.repaint();
            TXT_MD5.setText("");
            statusMessageLabel.setText("");
        }
    }

    @Action
    public void zakodovatText() {
        bitovepole = KRYApp.byteArrayToBitset(TXT_text.getText().getBytes());        
        //for (int i = 0; i < bitovepole.length(); i++) System.out.println( (bitovepole.get(i) ? 1 : 0));
        //System.out.println("Bity: " + bitovepole);
        if (vstup.getWidth()*vstup.getHeight() < 2*bitovepole.length())
            JOptionPane.showMessageDialog(null, "Text předložený k zaschäfrování je příliš velký a nositelský obrázek ho nepojme celý!\nObrázek má: "+vstup.getWidth()*vstup.getHeight()+" pixelů a text s redundancí potřebuje nejméně: " + 2*bitovepole.length() + " pixelů!", "KRY projekt2", 1);
        else {
            vystup = new BufferedImage(vstup.getWidth(), vstup.getHeight(), BufferedImage.TYPE_INT_RGB);
            progressBar.setMaximum(vstup.getHeight()*vstup.getWidth());
            new Vlakno(this).start();
        }
    }
    public String vratRetezec(BufferedImage img) {
        BitSet bs = new BitSet(img.getHeight()*img.getWidth());
        int k = 0;
        for (int i = 0; i < img.getHeight(); i++) {
            for (int j = 0; j < img.getWidth(); j++) {
                int pixel = img.getRGB(j, i);
                byte[] RGB = KRYApp.intToByteArray(pixel);
                BitSet data = KRYApp.byteToBitset(RGB[3]);
                bs.set(k, data.get(0));
                k++;
            }
        }
        byte [] retezec = KRYApp.bitsetToByteArray(bs);
        return new String(retezec);
    }
    @Action
    public void rozkodovatText() {        
        this.TXT_text.setText(vratRetezec(vstup));
        MessageDigest m;
        try {
            m = MessageDigest.getInstance("MD5");
            m.update(TXT_text.getText().getBytes(),0,TXT_text.getText().length());
            TXT_MD5.setText(new BigInteger(1,m.digest()).toString(16));
        } catch (NoSuchAlgorithmException ex) { System.err.println("Chyba MD5 hashishe!"); }
    }
    //Toto je sdeleni teroristicke jednotce operujici na uzemi CR. Neprodlene zlikvidujte spicky politicke moci a vyckejte dalsich prikazu...

    // Variables declaration - do not modify//GEN-BEGIN:variables
    public javax.swing.JButton BUT_decode;
    public javax.swing.JButton BUT_encode;
    private javax.swing.JButton BUT_prochazet;
    private javax.swing.JFileChooser FCH_soubor;
    private kry.JPictureGUI IMG_obrazek1;
    public kry.JPictureGUI IMG_obrazek2;
    public javax.swing.JTextField TXT_MD5;
    private javax.swing.JTextField TXT_soubor;
    private javax.swing.JTextArea TXT_text;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    public javax.swing.JProgressBar progressBar;
    public javax.swing.JLabel statusAnimationLabel;
    public javax.swing.JLabel statusMessageLabel;
    private javax.swing.JPanel statusPanel;
    // End of variables declaration//GEN-END:variables

    private final Timer messageTimer;
    public final Timer busyIconTimer;
    public final Icon idleIcon;
    private final Icon[] busyIcons = new Icon[15];
    private int busyIconIndex = 0;

    private JDialog aboutBox;
}
